@@ -1,14 +1,14 @@
-# Example for: alignment.id_table(), alignment.compare_sequences(),
+# Example for: Alignment.id_table(), Alignment.compare_sequences(),
 #              misc.principal_components(), misc.dendrogram()
 
 # Pairwise sequence identity between sequences in the alignment.
 
 from modeller import *
 
-env = environ()
+env = Environ()
 env.io.atom_files_directory = ['../atom_files']
 # Read all entries in this alignment:
-aln = alignment(env, file='toxin.ali')
+aln = Alignment(env, file='toxin.ali')
 
 # Access pairwise properties:
 s1 = aln[0]
@@ -20,7 +20,7 @@ print("%s and %s have %d equivalences, and are %.2f%% identical" % \
 aln.id_table(matrix_file='toxin_id.mat')
 
 # Calculate pairwise sequence similarities:
-mdl = model(env, file='2ctx', model_segment=('1:A', '71:A'))
+mdl = Model(env, file='2ctx', model_segment=('1:A', '71:A'))
 aln.compare_sequences(mdl, rr_file='$(LIB)/as1.sim.mat', max_gaps_match=1,
                       matrix_file='toxin.mat', variability_file='toxin.var')
 mdl.write(file='2ctx.var')
