@@ -3,10 +3,10 @@
 from modeller import *
 
 log.verbose()
-env = environ()
+env = Environ()
 env.io.atom_files_directory = ['../atom_files']
 
-mdl = model(env, file='2abx')
+mdl = Model(env, file='2abx')
 
 print("Mapping from residue indices to PDB residue and chain names:")
 for r in mdl.residues:
