@@ -1,16 +1,18 @@
 """Classes for handling template structures in alignments"""
 
 import _modeller
-from modeller import sequence, alnsequence, coordinates, modfile
+from modeller import alnsequence, coordinates, modfile
 
 __docformat__ = "epytext en"
 
+
 class Residue(coordinates.Residue, alnsequence.Residue):
     """A single residue in a template structure."""
 
     def __get_curv(self):
         x = _modeller.mod_structure_curvn_get(self.mdl._strucpt)
         return _modeller.mod_float1_get(x, self._num)
+
     def __set_curv(self, val):
         x = _modeller.mod_structure_curvn_get(self.mdl._strucpt)
         _modeller.mod_float1_set(x, self._num, val)
@@ -31,6 +33,7 @@ class Structure(coordinates.Coordinates, alnsequence.Sequence):
 
     def __repr__(self):
         return "Structure %s" % repr(self.code)
+
     def __str__(self):
         return "<%s>" % repr(self)
 
@@ -64,7 +67,8 @@ class Structure(coordinates.Coordinates, alnsequence.Sequence):
                                             aln.env.io.modpt,
                                             aln.env.libs.modpt)
             self.__read_coord = True
-        return _modeller.mod_alignment_structure_get(self.aln.modpt, self.__num)
+        return _modeller.mod_alignment_structure_get(self.aln.modpt,
+                                                     self.__num)
 
     def __get_cdpt(self):
         return _modeller.mod_structure_cd_get(self.__get_strucpt())
