@@ -4,9 +4,11 @@ import _modeller
 from modeller import modfile
 from modeller.util.modobject import ModObject
 from modeller.util import array
+from modeller.util.deprecation import _deprecation_handler
 
 __docformat__ = "epytext en"
 
+
 class Density(ModObject):
     """Holds all information from an EM (electron microscopy) density file"""
     _modpt = None
@@ -45,12 +47,10 @@ class Density(ModObject):
             px = py = pz = 0.
             read_origin = True
         fh = modfile._get_filehandle(file, 'rb')
-        return _modeller.mod_density_read(self._modpt, fh.file_pointer,
-                                          em_density_format,
-                                          em_map_size, filter_type, voxel_size,
-                                          resolution, filter_values,
-                                          density_type, px, py, pz, read_origin,
-                                          cc_func_type)
+        return _modeller.mod_density_read(
+            self._modpt, fh.file_pointer, em_density_format, em_map_size,
+            filter_type, voxel_size, resolution, filter_values, density_type,
+            px, py, pz, read_origin, cc_func_type)
 
     def grid_search(self, em_pdb_name, chains_num, em_density_format='XPLOR',
                     num_structures=1, dock_order='INPUT', start_type='CENTER',
@@ -58,39 +58,45 @@ class Density(ModObject):
                     angular_step_size=0, temperature=293.0,
                     best_docked_models=1, em_fit_output_file='em_fit.out'):
         """Dock a structure into the EM density map"""
-        return _modeller.mod_density_grid_search(self._modpt, em_density_format,
-                                                 num_structures, dock_order,
-                                                 start_type, translate_type,
-                                                 number_of_steps,
-                                                 angular_step_size,
-                                                 temperature,
-                                                 best_docked_models,
-                                                 em_fit_output_file,
-                                                 em_pdb_name, chains_num)
+        return _modeller.mod_density_grid_search(
+            self._modpt, em_density_format, num_structures, dock_order,
+            start_type, translate_type, number_of_steps, angular_step_size,
+            temperature, best_docked_models, em_fit_output_file, em_pdb_name,
+            chains_num)
 
     def __get_resolution(self):
         return _modeller.mod_density_resolution_get(self._modpt)
+
     def __set_resolution(self, val):
         _modeller.mod_density_resolution_set(self._modpt, val)
+
     def __get_sigma_factor(self):
         return _modeller.mod_density_sigma_factor_get(self._modpt)
+
     def __set_sigma_factor(self, val):
         _modeller.mod_density_sigma_factor_set(self._modpt, val)
+
     def __get_grid_sqr_sum(self):
         return _modeller.mod_density_grid_sqr_sum_get(self._modpt)
+
     def __get_grid(self):
         return array.Float3DArray(_modeller.mod_density_grid_get(self._modpt),
                                   (_modeller.mod_density_nz_get(self._modpt),
                                    _modeller.mod_density_ny_get(self._modpt),
                                    _modeller.mod_density_nx_get(self._modpt)))
+
     def __get_norm_factor(self):
         return _modeller.mod_density_norm_factor_get(self._modpt)
+
     def __get_voxel_size(self):
         return _modeller.mod_density_vox_size_get(self._modpt)
+
     def __get_px(self):
         return _modeller.mod_density_px_get(self._modpt)
+
     def __get_py(self):
         return _modeller.mod_density_py_get(self._modpt)
+
     def __get_pz(self):
         return _modeller.mod_density_pz_get(self._modpt)
 
@@ -108,7 +114,6 @@ class Density(ModObject):
 
 
 # Modeller 9 compatibility
-from modeller.util.deprecation import _deprecation_handler
 class density(Density):
     def __init__(self, *args, **keys):
         _deprecation_handler._init_class(density)
